// Copyright (c) Mito
import React, { useState, useEffect, Fragment } from 'react';
import { ModalEnum } from './modals';
import DefaultModal from '../DefaultModal';
// import css
import "../../../css/sitewide/all-modals.css";
import "../../../css/import-modal.css";
import TextButton from '../elements/TextButton';
import Select from '../elements/Select';
import DropdownItem from '../elements/DropdownItem';
export const getDfNameError = (pythonCode, newDfNames, existingDfNames) => {
    for (let i = 0; i < newDfNames.length; i++) {
        // Invalid if it's not in the Python
        if (!pythonCode.includes(newDfNames[i])) {
            return `Error: ${newDfNames[i]} is not a name of a variable in your code.`;
        }
        // Or if it's already the name of a sheet
        if (existingDfNames.indexOf(newDfNames[i]) !== -1) {
            return `Error: ${newDfNames[i]} is already the name of a sheet. Please choose a different name.`;
        }
    }
    return undefined;
};
/*
  A modal that allows a user to change what files they import when
  replaying an analysis.
*/
const ReplayImportModal = (props) => {
    // Params for a simple import
    const [fileNames, setFileNames] = useState([]);
    const [importedFilesByStep, setImportedFilesByStep] = useState(props.importSummaries);
    async function getDataFiles() {
        const dataFiles = await props.mitoAPI.getDataFiles();
        setFileNames(dataFiles);
        // We then set the imports to the first datafile, as we actually want
        // to make sure they are updated. Otherwise, if the user just clicks
        // accept, then these imports won't be defined
        Object.keys(props.importSummaries).forEach(stepIndex => {
            props.importSummaries[stepIndex].forEach((fileName, fileIndex) => {
                const newFile = dataFiles.length > 0 ? dataFiles[0] : '';
                updateImportedFile(stepIndex, fileIndex, newFile);
            });
        });
    }
    useEffect(() => {
        // To see an explination, read here: https://medium.com/better-programming/how-to-fetch-data-from-an-api-with-react-hooks-9e7202b8afcd
        // TL;DR: we load the data after the component renders
        void getDataFiles();
    }, []); // empty array is key to have this run only once
    /*
        For a simple import, updates the imported file that is saved for that specific import
    */
    const updateImportedFile = (stepIndex, index, newImport) => {
        const newImportedFilesByStep = JSON.parse(JSON.stringify(importedFilesByStep));
        newImportedFilesByStep[stepIndex][index] = newImport;
        setImportedFilesByStep(newImportedFilesByStep);
    };
    const getPreviousFileNamesLabels = (previousFileNames) => {
        return previousFileNames.map(fileName => (React.createElement("p", { className: 'previous-file-name-label', key: fileName },
            " ",
            fileName,
            " ")));
    };
    const clickImport = async () => {
        await props.mitoAPI.sendUseExistingAnalysisUpdateMessage(props.analysisName, importedFilesByStep);
        props.setUIState((prevUIState) => {
            return Object.assign(Object.assign({}, prevUIState), { currOpenModal: { type: ModalEnum.None } });
        });
    };
    return (React.createElement(DefaultModal, { header: `Update Imported Data`, modalType: ModalEnum.ReplayImport, viewComponent: React.createElement(Fragment, null,
            React.createElement("p", null, "Change your previously-used data source to re-run this analysis on new data."),
            Object.keys(importedFilesByStep).map((stepIndex) => {
                const previousFileNames = importedFilesByStep[stepIndex];
                const originalFileNamesLabels = getPreviousFileNamesLabels(props.importSummaries[stepIndex]);
                return (React.createElement("div", { key: stepIndex },
                    React.createElement("div", { className: 'modal-element-label mt-2' },
                        "Select the new version of each file for Step ",
                        stepIndex,
                        "."),
                    React.createElement("div", { className: 'import-files-old-and-new-container' },
                        React.createElement("div", { className: 'previous-file-name-labels-container' }, originalFileNamesLabels),
                        React.createElement("div", { className: 'import-files-select' }, previousFileNames.map((previousFileName, idx) => {
                            return (React.createElement(Select, { key: previousFileName, value: previousFileName, onChange: (value) => {
                                    updateImportedFile(stepIndex, idx, value);
                                }, width: 'small' }, fileNames.map(fileName => {
                                return (React.createElement(DropdownItem, { key: fileName, title: fileName }));
                            })));
                        })))));
            })), buttons: React.createElement(Fragment, null,
            React.createElement(TextButton, { variant: 'light', width: 'small', onClick: () => {
                    props.setUIState((prevUIState) => {
                        return Object.assign(Object.assign({}, prevUIState), { currOpenModal: { type: ModalEnum.None } });
                    });
                } }, "Close"),
            React.createElement(TextButton, { variant: 'dark', width: 'small', onClick: clickImport }, "Replay")) }));
};
export default ReplayImportModal;
//# sourceMappingURL=ReplayImportModal.js.map