import { useEffect } from "react";
/*
    This hook detects when the user makes any click, and then calls the passed function.
    
    When noActionClickElement is provided, any click inside noActionClickElement does not trigger the function.

    This is used to close the dropdown when the user makes any click.

    Adapted from https://stackoverflow.com/questions/54560790/detect-click-outside-react-component-using-hooks
*/
export function useCallOnAnyClick(onClick, noActionClickElement) {
    const handleClick = (event) => {
        // If the click was inside the noActionClickElement, then don't do anything
        if (noActionClickElement !== undefined &&
            noActionClickElement.current !== null &&
            noActionClickElement.current.contains(event.target)) {
            return;
        }
        else {
            /*
                We delay actually calling of the function by 100 miliseconds, just in case the user's click is
                actually on the dropdown open/close button. This makes sure that we don't close and then
                immediately reopen the component.

                It is an ugly hack, but it appears to work for now!
            */
            setTimeout(() => {
                onClick();
            }, 100);
        }
    };
    useEffect(() => {
        document.addEventListener('click', handleClick, true);
        return () => {
            document.removeEventListener('click', handleClick, true);
        };
    });
}
//# sourceMappingURL=useCallOnAnyClick.js.map