// Copyright (c) Mito
import React, { Fragment, useEffect, useState } from 'react';
import MultiToggleBox from '../../../elements/MultiToggleBox';
import Select from '../../../elements/Select';
import Col from '../../../spacing/Col';
import Row from '../../../spacing/Row';
import { getAllDoesNotContainsFilterValues } from '../FilterAndSortTab/filter/utils';
import MultiToggleItem from '../../../elements/MultiToggleItem';
import DropdownItem from '../../../elements/DropdownItem';
var UniqueValueSortType;
(function (UniqueValueSortType) {
    UniqueValueSortType["ASCENDING_ALPHABETICAL"] = "Ascending Value";
    UniqueValueSortType["DESCENDING_ALPHABETICAL"] = "Descending Value";
    UniqueValueSortType["ASCENDING_PERCENT_OCCURENCE"] = "Ascending Occurence";
    UniqueValueSortType["DESCENDING_PERCENT_OCCURENCE"] = "Descending Occurence";
})(UniqueValueSortType || (UniqueValueSortType = {}));
const sortUniqueValueCounts = (uniqueValueCounts, uniqueValueSortType) => {
    if (uniqueValueSortType === UniqueValueSortType.ASCENDING_ALPHABETICAL) {
        return uniqueValueCounts.sort(function (a, b) {
            if (a.value < b.value) {
                return -1;
            }
            if (a.value > b.value) {
                return 1;
            }
            return 0;
        });
    }
    else if (uniqueValueSortType === UniqueValueSortType.DESCENDING_ALPHABETICAL) {
        return uniqueValueCounts.sort(function (a, b) {
            if (a.value > b.value) {
                return -1;
            }
            if (a.value < b.value) {
                return 1;
            }
            return 0;
        });
    }
    else if (uniqueValueSortType === UniqueValueSortType.ASCENDING_PERCENT_OCCURENCE) {
        return uniqueValueCounts.sort(function (a, b) {
            return a.percentOccurence - b.percentOccurence;
        });
    }
    else {
        return uniqueValueCounts.sort(function (a, b) {
            return b.percentOccurence - a.percentOccurence;
        });
    }
};
export function ValuesTab(props) {
    const [loading, setLoading] = useState(true);
    const [uniqueValueCounts, setUniqueValueCounts] = useState([]);
    const [uniqueValueSortType, setUniqueValueSortType] = useState(UniqueValueSortType.ASCENDING_ALPHABETICAL);
    // We only load the uniqueValueCounts once on initial render of the value section
    useEffect(() => {
        void loadUniqueValueCounts();
    }, []);
    async function loadUniqueValueCounts() {
        const _uniqueValueObjs = await props.mitoAPI.getUniqueValueCounts(props.selectedSheetIndex, props.columnID);
        if (_uniqueValueObjs !== undefined) {
            /*
                Add back all of the values that were filtered out of the column, so the user can toggle
                them back on. Note that this lets users toggle them back on even if they were removed in a previous step!
            */
            const allDoesNotContainsFilters = getAllDoesNotContainsFilterValues(props.filters, props.columnMitoType);
            allDoesNotContainsFilters.forEach(key => {
                _uniqueValueObjs.push({
                    value: key,
                    percentOccurence: 0,
                    countOccurence: 0,
                    isNotFiltered: false,
                });
            });
            setUniqueValueCounts(_uniqueValueObjs);
        }
        else {
            setUniqueValueCounts([]);
        }
        setLoading(false);
    }
    /*
        Helper function for getting the index of the UniqueValueCount in UniqueValueCounts from the index
        of the UniqueValueCount in the searchedUniqueValueCounts. It exploits the invariant that
        these are _unique value_ counts.
    */
    const getUniqueValueCountIndexFromSortedIndex = (index) => {
        const value = sortedUniqueValueCounts[index].value;
        return uniqueValueCounts.findIndex(uniqueValueCount => {
            return uniqueValueCount.value === value;
        });
    };
    const sortedUniqueValueCounts = sortUniqueValueCounts(uniqueValueCounts, uniqueValueSortType);
    return (React.createElement(Fragment, null,
        React.createElement(Row, { justify: 'space-between' },
            React.createElement(Col, { flex: '1', offsetRight: 1 },
                React.createElement("p", { className: 'text-header-2' }, "Unique Values")),
            React.createElement(Col, null,
                React.createElement(Select, { value: uniqueValueSortType, onChange: (newUniqueValueSortType) => {
                        setUniqueValueSortType(newUniqueValueSortType);
                    }, width: 'medium', dropdownWidth: 'medium' }, Object.values(UniqueValueSortType).map(sortType => {
                    return (React.createElement(DropdownItem, { key: sortType, title: sortType }));
                })))),
        React.createElement("div", { style: { height: 'calc(100% - 40px)' } },
            React.createElement(MultiToggleBox, { searchable: true, loading: loading }, sortedUniqueValueCounts.map((uniqueValueCount, index) => {
                return ((React.createElement(MultiToggleItem, { key: index, title: uniqueValueCount.value.toString(), rightText: uniqueValueCount.countOccurence + ' (' + uniqueValueCount.percentOccurence.toFixed(2).toString() + '%' + ')', toggled: uniqueValueCount.isNotFiltered, index: index, onToggle: () => {
                        // Manually change the toggle status so it updates instantaneously
                        const uniqueValueCountIndex = getUniqueValueCountIndexFromSortedIndex(index);
                        setUniqueValueCounts(oldUniqueValueCounts => {
                            const newUniqueValueCounts = oldUniqueValueCounts.slice();
                            newUniqueValueCounts[uniqueValueCountIndex].isNotFiltered = !uniqueValueCounts[uniqueValueCountIndex].isNotFiltered;
                            return newUniqueValueCounts;
                        });
                        props.toggleExclusiveFilters([uniqueValueCount.value]);
                    } })));
            })))));
}
//# sourceMappingURL=ValuesTab.js.map